@@ -12,10 +12,7 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/provider-local",
-    "0.0.244",
-    __name__[0:-6],
-    "provider-local@0.0.244.jsii.tgz",
+    "@cdktf/provider-local", "0.1.56", __name__[0:-6], "provider-local@0.1.56.jsii.tgz"
 )
 
 __all__ = [
